.. documentation master file, created by
   sphinx-quickstart on Sat Jan 21 19:11:14 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


==========================================================================
tricycle: Experimental extensions for Trio, the friendly async I/O library
==========================================================================

``tricycle`` is a library of extensions to `Trio <https://trio.readthedocs.io/en/latest/>`__ which are a bit too specialized or experimental to include in Trio directly.

.. toctree::
   :maxdepth: 2

   reference.rst
   history.rst

====================
 Indices and tables
====================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`
